########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

#############################################################################################################
# While implementing the RI, this version of the code, written at NCHS, also updates the version used in:
#
# Borrell, L.N., M. Talih (2012). 
# Examining periodontal disease disparities among U.S. adults 20 years of age and older: 
# NHANES III (1988-1994) and NHANES 1999-2004. 
# Public Health Reports, 127, pp.497-506.
#
# Borrell, L.N., M. Talih (2011). 
# A Symmetrized Theil index measure of health disparities: 
# An example using dental caries in U.S. children and adolescents. 
# Statistics in Medicine, 30 (3), pp. 277-90. 
# First published online 5 November 2010. 
# DOI: 10.1002/sim.4114.
#
# !! However, please use at your own risk if changing parameter settings !!
# !! Code not tested extensively for limit cases or different data sources !!
##############################################################################################################

######################################################
## This is the master file to source into R ##########
#
# eg., from the command prompt:
# "R --no-restore --no-save --slave < MasterFile***.R"
######################################################


###################################################################################################
# NOTES:
#
# Program is currently set to compute overall, within, and between indices for SRI.
# Also returns standard errors, p-values and 95% CI based on Taylor linearization,
# as well as Balanced Repeated Replication (BRR) and rescaled bootstrap (B=500 replications).
#
####################################################################################################

################################################
## Attach Lumley's 'survey' package (REQUIRED) (change path for lib.loc as needed)

library('survey')

#####################################
## Some high-level user parameters ##
#####################################

R.in = "GenerateReport.R"           # Specify input file

DATA.in = "DataSetup44.R"           # Data setup file name

FUN.in = "Theil-Functions45.R"      # File name for work-horse functions

in.PREFIX = "theil45"               # Filename prefix used to indicate version of code for input files

r03.PATH = "C:/***/pubperio/"  # Specify directory path

cmn.PATH = "common/"                  # Specify subdirectory for syntax files common 

in.PATH = "nhanes0104/"               # Specify subdirectory for input files

out.PATH = "nhanes0104/output-files/" # Specify subdirectory for output files

options(width=164)                  # width of page for report format

DIGITS = 6    # number of significant digits to use in generated report.

FAY.RHO = 0.5 # Traditional Balanced Repeated Replication (BRR) with Fay's adjustment.
              # Fay, R.E. (1989). Theoretical Application of Weighting for Variance Calculation.
              # Proceedings of the Section on Survey Research Methods of the American Statistical Association
              # pp. 212-217.

B = 500      # specifying a positive value of B, e.g. B = 500, generates
           # bootstrap weights cf. appendix in Cheng, Han & Gansky (2008).
           # THIS METHOD WILL CONSIDERABLY INCREASE RUNNING TIME.
           # Based on: Rao, J.N.K., Wu, C.F.J., and Yue, K. (1992). Some Recent Work in Resampling Methods.
           # Survey Methodology, 18, 209-217.

SEED = 132 # To set random seed for bootstrap method, used only if B > 0.

## range of disparity aversion parameter to loop through
alpha.range = c(seq(0.5, 1, 0.05), 2^(1:8))

## types of HDI to loop through: SRPW = population-weighted SRI; SREW = equally-weighted SRI.
index.type = c("SRPW", "SREW")

## Note: SRPW with parameter alpha=1 is the STI; SREW with alpha=1 is an equally-weighted STI.

################################################################################################
## Read in the R functions to calculate/output the Symmetrized Renyi index and its decomposition

cat("\n Reading in R functions...")
source(paste(r03.PATH, cmn.PATH, FUN.in, sep=""))
cat("... done!\n")

cat("\n NHANES 2001-2004 data \n")
source(paste(r03.PATH, in.PATH, R.in, sep=""))

#################################
# Last modified 11 December 2012. MT.
#################################





