/* SAS syntax for HP2020 objective OH-5 */
/* Reference: Talih, M. (2012). A reference-invariant health disparity index based on Renyi divergence. Annals of Applied Statistics.*/
/* Prepared by Makram Talih at NCHS */
/* December 2012 */

LIBNAME C '\\***\PERIO_R03'; *set to desired library location;

DATA PERIO0104;
SET C.NHANES0104; *NHANES0104 was created from the SAS xpt files directly using only the NHANES 2001-02 and the 2003-04 surveys*;

/**TOOTH COUNT (two surveys use different variables names)**/

array crown0102 (28) OHD02TC OHD03TC OHD04TC
                 	OHD05TC OHD06TC OHD07TC OHD08TC OHD09TC OHD10TC
                 	OHD11TC OHD12TC OHD13TC OHD14TC OHD15TC 
                 	OHD18TC OHD19TC OHD20TC OHD21TC OHD22TC 
                 	OHD23TC OHD24TC OHD25TC OHD26TC OHD27TC OHD28TC 
                 	OHD29TC OHD30TC OHD31TC;

array crown0203 (28) OHX02TC OHX03TC OHX04TC
                 	OHX05TC OHX06TC OHX07TC OHX08TC OHX09TC OHX10TC
                 	OHX11TC OHX12TC OHX13TC OHX14TC OHX15TC 
                 	OHX18TC OHX19TC OHX20TC OHX21TC OHX22TC 
                 	OHX23TC OHX24TC OHX25TC OHX26TC OHX27TC OHX28TC 
                 	OHX29TC OHX30TC OHX31TC;

/*keep track of count of permanent teeth present*/

PERMCOUNT=0;
do i=1 to 28;
	if SURVEY = 2 then do;
		if crown0102 (i)=2 then PERMCOUNT=PERMCOUNT+1;
	end;
	if SURVEY = 3 then do;
		if crown0203 (i)=2 then PERMCOUNT=PERMCOUNT+1;
	end;
end;
drop i;

/**POCKET DEPTH and CAL IN PROXIMAL SITES ONLY**/

array ipkd(56) 	OHD02PCD OHD02PCS OHD03PCD OHD03PCS OHD04PCD OHD04PCS
				OHD05PCD OHD05PCS OHD06PCD OHD06PCS OHD07PCD OHD07PCS OHD08PCD OHD08PCS
				OHD09PCD OHD09PCS OHD10PCD OHD10PCS OHD11PCD OHD11PCS OHD12PCD OHD12PCS
				OHD13PCD OHD13PCS OHD14PCD OHD14PCS OHD15PCD OHD15PCS 
				OHD18PCD OHD18PCS OHD19PCD OHD19PCS OHD20PCD OHD20PCS
				OHD21PCD OHD21PCS OHD22PCD OHD22PCS OHD23PCD OHD23PCS OHD24PCD OHD24PCS
				OHD25PCD OHD25PCS OHD26PCD OHD26PCS OHD27PCD OHD27PCS OHD28PCD OHD28PCS
				OHD29PCD OHD29PCS OHD30PCD OHD30PCS OHD31PCD OHD31PCS;

array ical (56) OHD02LAD OHD02LAS OHD03LAD OHD03LAS OHD04LAD OHD04LAS
				OHD05LAD OHD05LAS OHD06LAD OHD06LAS OHD07LAD OHD07LAS OHD08LAD OHD08LAS
				OHD09LAD OHD09LAS OHD10LAD OHD10LAS OHD11LAD OHD11LAS OHD12LAD OHD12LAS
				OHD13LAD OHD13LAS OHD14LAD OHD14LAS OHD15LAD OHD15LAS 
 				OHD18LAD OHD18LAS OHD19LAD OHD19LAS OHD20LAD OHD20LAS
				OHD21LAD OHD21LAS OHD22LAD OHD22LAS OHD23LAD OHD23LAS OHD24LAD OHD24LAS
				OHD25LAD OHD25LAS OHD26LAD OHD26LAS OHD27LAD OHD27LAS OHD28LAD OHD28LAS
				OHD29LAD OHD29LAS OHD30LAD OHD30LAS OHD31LAD OHD31LAS;

/* keep track of number of (permanent) teeth with valid PKD and (or?) CAL measurements on two interproximal sites for each tooth */
tprox=0;
do i=1,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55; /*tracks pairs of sites*/
	*if ical (i) ne 99 and ical (i) ne . and ical (i+1) ne 99 and ical (i+1) ne . and ipkd (i) ne 99 and ipkd (i) ne . and ipkd (i+1) ne 99 and ipkd (i+1) ne . then tprox=tprox+1;
	if (ical (i) ne 99 and ical (i) ne . and ical (i+1) ne 99 and ical (i+1) ne .) or (ipkd (i) ne 99 and ipkd (i) ne . and ipkd (i+1) ne 99 and ipkd (i+1) ne .) or (ical (i) ne 99 and ical (i) ne . and ipkd (i+1) ne 99 and ipkd (i+1) ne .) or (ipkd (i) ne 99 and ipkd (i) ne . and ical (i+1) ne 99 and ical (i+1) ne .) then tprox=tprox+1;
end;
drop i;

*HP2020 denominator definition requires at least two (permanent) teeth with a valid perio measurement on two interproximal sites for each tooth;

/* Number of adults aged 45-74 years with 2 of 28 possible
 * permanent teeth present (exclusive of 3rd molars), and valid
 * periodontal probing measurements for 2 permanent teeth,
 * at 2 interproximal sites (mesial or distal) on each tooth. 
 */

/***PKD***/

* proceed with PKD calculations only if there are at least two (permanent) teeth with two valid interproximal sites on each;
if tprox >= 2 then do;
	*proxpkd0=0;
	*proxpkd1=0;
	*proxpkd2=0;
	*proxpkd3=0;
	*proxpkd4=0;
	*proxpkd5=0;
	*proxpkd6=0;
	*proxpkd7=0;
	*proxpkd8=0;
	*proxpkd9=0;
	*proxpkd10=0;
	*proxpkd11=0;
	*proxpkd12=0;
	*proxpkd13=0;
	*proxpkd_1=0; /*comment out unused variables*/
	proxpkd22=0;
	proxpkd33=0;
	proxpkd44=0;
	proxpkd55=0;
	proxpkd66=0;
	proxpkd77=0;

	do i=1 to 56;
		if ipkd (i) ne 99 and ipkd (i) ne . then do;
			*if ipkd (i)=0 then proxpkd0=proxpkd0+1;
			*if ipkd (i)=1 then proxpkd1=proxpkd1+1;
			*if ipkd (i)=2 then proxpkd2=proxpkd2+1;
			*if ipkd (i)=3 then proxpkd3=proxpkd3+1;
			*if ipkd (i)=4 then proxpkd4=proxpkd4+1;
			*if ipkd (i)=5 then proxpkd5=proxpkd5+1;
			*if ipkd (i)=6 then proxpkd6=proxpkd6+1;
			*if ipkd (i)=7 then proxpkd7=proxpkd7+1;
			*if ipkd (i)=8 then proxpkd8=proxpkd8+1;
			*if ipkd (i)=9 then proxpkd9=proxpkd9+1;
			*if ipkd (i)=10 then proxpkd10=proxpkd10+1;
			*if ipkd (i)=11 then proxpkd11=proxpkd11+1;
			*if ipkd (i)=12 then proxpkd12=proxpkd12+1;
			*if ipkd (i)=13 then proxpkd13=proxpkd13+1;
			*if ipkd (i) ge 1 then proxpkd_1=proxpkd_1+1; /*comment out unused variables*/
			if ipkd (i) ge 2 then proxpkd22=proxpkd22+1;
			if ipkd (i) ge 3 then proxpkd33=proxpkd33+1;
			if ipkd (i) ge 4 then proxpkd44=proxpkd44+1;
			if ipkd (i) ge 5 then proxpkd55=proxpkd55+1;
			if ipkd (i) ge 6 then proxpkd66=proxpkd66+1;
			if ipkd (i) ge 7 then proxpkd77=proxpkd77+1;
		end;
	end;
end;
drop i;

/**PREVALENCE OF POCKET DEPTH (modified for consistency with HP2020 op def)**/;

/* first, keep track of occurence of PD ge 5mm on two sites in same tooth (used below)*/
if tprox >= 2 then do;
	tproxpkd55=0;
	do i=1,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55;
		if ipkd (i) ne 99 and ipkd (i) ne . and ipkd (i+1) ne 99 and ipkd (i+1) ne . then do;
			if ipkd(i) ge 5 and ipkd(i+1) ge 5 then tproxpkd55=tproxpkd55+1;
		end;
	end;
end;
drop i;

* for severe perio, HP2020 definition requires at least one with PD ge 5mm AND...;
if tprox >= 2 then do;
	if proxpkd55 ne . then do;
		if proxpkd55 ge 1 then pkdprev51=1;
		else pkdprev51=0;
	end;
end;

* for moderate perio, HP2020 definition requires at least two with PD ge 5mm (but not on same tooth) OR...;
if tprox >= 2 then do;
	if proxpkd55 ne . then do;
 		if proxpkd55 ge 3 then pkdprev52=1; * three sites always involve at least two teeth;
		else if proxpkd55 = 2 and tproxpkd55 = 0 then pkdprev52=1; * ensure not on same tooth;
		else pkdprev52=0;
	end;
end; 


/***CAL***/

* proceed with CAL calculations only if there are at least two teeth with two valid interproximal sites on each;
if tprox >= 2 then do;
	*calprox0=0;
	*calprox1=0;
	*calprox2=0;
	*calprox3=0;
	*calprox4=0;
	*calprox5=0;
	*calprox6=0;
	*calprox7=0;
	*calprox8=0;
	*calprox9=0;
	*calprox10=0;
	*calprox11=0;
	*calprox12=0;
	*calprox13=0;
	*calprox14=0;
	*calprox15=0;
	*calprox16=0;
	*calprox17=0;
	*calprox18=0;
	*calprox19=0;
	*calprox20=0;
	*calprox_1=0;  /*comment out unused variables*/
	calprox22=0;
	calprox33=0;
	calprox44=0;
	calprox55=0;
	calprox66=0;
	calprox77=0;

	do i=1 to 56;
		if ical (i) ne 99 and ical (i) ne . then do;
			*if ical (i)=0 then calprox0=calprox0+1;
			*if ical (i)=1 then calprox1=calprox1+1;
			*if ical (i)=2 then calprox2=calprox2+1;
			*if ical (i)=3 then calprox3=calprox3+1;
			*if ical (i)=4 then calprox4=calprox4+1;
			*if ical (i)=5 then calprox5=calprox5+1;
			*if ical (i)=6 then calprox6=calprox6+1;
			*if ical (i)=7 then calprox7=calprox7+1;
			*if ical (i)=8 then calprox8=calprox8+1;
			*if ical (i)=9 then calprox9=calprox9+1;
			*if ical (i)=10 then calprox10=calprox10+1;
			*if ical (i)=11 then calprox11=calprox11+1;
			*if ical (i)=12 then calprox12=calprox12+1;
			*if ical (i)=13 then calprox13=calprox13+1;
			*if ical (i)=14 then calprox10=calprox14+1;
			*if ical (i)=15 then calprox11=calprox15+1;
			*if ical (i)=16 then calprox12=calprox16+1;
			*if ical (i)=17 then calprox13=calprox17+1;
			*if ical (i)=18 then calprox10=calprox18+1;
			*if ical (i)=19 then calprox11=calprox19+1;
			*if ical (i)=20 then calprox12=calprox20+1;
			*if ical (i) ge 1 then calprox_1=calprox_1+1; /*comment out unused variables*/
			if ical (i) ge 2 then calprox22=calprox22+1;
			if ical (i) ge 3 then calprox33=calprox33+1;
			if ical (i) ge 4 then calprox44=calprox44+1;
			if ical (i) ge 5 then calprox55=calprox55+1;
			if ical (i) ge 6 then calprox66=calprox66+1;
			if ical (i) ge 7 then calprox77=calprox77+1;
		end;
	end;
end;
drop i;


/**PREVALENCE OF CAL (modified for consistency with HP2020 op def)**/;

/* first, keep track of occurence of CAL ge 4mm on two sites in same tooth (used below)*/
if tprox >= 2 then do;
	tcalprox44=0;
	do i=1,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55;
	    if ical (i) ne 99 and ical (i) ne . and ical (i+1) ne 99 and ical (i+1) ne . then do;
			if ical(i) ge 4 and ical(i+1) ge 4 then tcalprox44=tcalprox44+1;
		end;
	end;
end;
drop i;

/* also keep track of occurence of CAL ge 6mm on two sites in same tooth (used below)*/
if tprox >= 2 then do;
	tcalprox66=0;
	do i=1,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33,35,37,39,41,43,45,47,49,51,53,55;
	    if ical (i) ne 99 and ical (i) ne . and ical (i+1) ne 99 and ical (i+1) ne . then do;
			if ical(i) ge 6 and ical(i+1) ge 6 then tcalprox66=tcalprox66+1;
		end;
	end;
end;
drop i;

* moderate perio: HP2020 definition requires at least two with CAL ge 4mm (but not on same tooth) OR...;
if tprox >= 2 then do;
	if calprox44 ne . then do;
		if calprox44 ge 3 then calprev42=1; * three sites always involve at least two teeth;
		else if calprox44 = 2 and tcalprox44 = 0 then calprev42=1; * ensure not on same tooth;
		else calprev42=0;
	end;
end;

* severe perio: HP2020 definition requires at least two with CAL ge 6mm (but not on same tooth) AND...;
if tprox >= 2 then do;
	if calprox66 ne . then do;
 		if calprox66 ge 3 then calprev62=1; * three sites always involve at least two teeth;
		else if calprox66 = 2 and tcalprox66 = 0 then calprev62=1; * ensure not on same tooth;
		else calprev62=0;
	end;
end;

*****HP2020 PERIO DEFINITION ******;

/* population (denominator) is persons with at least two permanent teeth present
 * and have at least two teeth with valid perio measurement at two interproximal sites on each tooth */

if PERMCOUNT >= 2 and tprox >= 2 then do; /*PERMCOUNT condition is redundant, but kept for clarity */

	/*HP2020 severe: at least two sites (not on same tooth) with >= 6 mm CAL and at least one with PD >= 5*/
	if pkdprev51 = 1 and calprev62 = 1 then HP2020sev=1;
	else HP2020sev=0;

	/*HP2020 moderate: at least two sites with >= 4 mm CAL (not on same tooth) 
					or at least two sites with PD >= 5 (not on same tooth)*/
	if HP2020sev=0 and (pkdprev52 = 1 or calprev42 = 1) then HP2020mod=1; *(exclude severe);
	else HP2020mod=0;

	/* moderate or severe perio */
	if HP2020mod = 1 or HP2020sev = 1 then HP2020perio = 1;
	else HP2020perio = 0;

	/*number of sites affected with CAL >= 4mm */
	HP2020cal4 = calprox44;

    /*number of sites affected with CAL >= 6mm */
 	HP2020cal6 = calprox66;

	/*number of sites affected with PD >= 5mm */
 	HP2020pkd5 = proxpkd55;

end;

RUN;

