/* SAS syntax for HP2020 objective OH-5 */
/* Reference: Talih, M. (2012). A reference-invariant health disparity index based on Renyi divergence. Annals of Applied Statistics.*/
/* Prepared by Makram Talih at NCHS */
/* December 2012 */

LIBNAME C '***\PERIO_R03'; *set to desired library location;

DATA NH0104_rev;
set PERIO0104;

****CREATING 4-YEAR WEIGHT VARIABLES (for combining only two surveys)**;
IF SURVEY= 2 THEN DO;
	WTINT22YR=(0.5*WTINT2YR);
	WTMEC22YR=(0.5*WTMEC2YR);
END;

IF SURVEY=3 THEN DO;
	WTINT22YR=(0.5*WTINT2YR);
	WTMEC22YR=(0.5*WTMEC2YR);
END;

/* rename to keep compatibility with NHANES III nomenclature */

RENAME WTMEC22YR=WTPFEX6;  ***weights***;
RENAME SDMVSTRA=SDPSTRA6; ***STRATA***;
RENAME SDMVPSU=SDPPSU6;   ***PSU***;

**Sociodemographic variables**;

*OLD EDUCATION CATEGORIES: <12, 12 AND >12;
IF DMDEDUC=1 THEN EDUC=1;
ELSE IF DMDEDUC=2 THEN EDUC=2;
ELSE IF DMDEDUC=3 THEN EDUC=3;
ELSE IF DMDEDUC IN (7,9) or DMDEDUC=. THEN EDUC=4; **MISSING**;

*NEW EDUCATION CATEGORIES: 1=less than high school, 2=high school graduate, 3=some college or AA, 4 = college graduate or above, 5=missing;
IF DMDEDUC2 IN (1,2) THEN NEDUC=1;
ELSE IF DMDEDUC2=3 THEN NEDUC=2;
ELSE IF DMDEDUC2=4 THEN NEDUC=3;
ELSE IF DMDEDUC2=5 THEN NEDUC=4;
ELSE IF DMDEDUC2 IN (7,9) or DMDEDUC2=. THEN NEDUC=5; **MISSING**;

***Family Income: <= $19,999, $20,000-$44,999, $45,000+ AND MISSING;**;
IF 1<= INDFMINC<=4  THEN INC3=1;
ELSE IF 5<=INDFMINC<=7 THEN INC3=2;
ELSE IF 8<=INDFMINC<=11 THEN INC3=3;
ELSE IF 12<=INDFMINC<=99 OR INDFMINC=. THEN INC3=4;

**HOUSEHOLD INCOME: <= $19,999, $20,000-$44,999, $45,000+ AND MISSING;**;
IF 1<= INDHHINC<=4 THEN HINC3=1;
ELSE IF 5<=INDHHINC<=7 THEN HINC3=2;
ELSE IF 8<=INDHHINC<=11 THEN HINC3=3;
ELSE IF 77<=INDHHINC<=99 THEN HINC3=4;

***PIR****;
IF 0<=INDFMPIR<=1.850 THEN PIR=1;
ELSE IF 1.86<=INDFMPIR<=3.50 THEN PIR=2;
ELSE IF 3.51<=INDFMPIR<=5 THEN PIR=3;
ELSE IF INDFMPIR=. THEN PIR=4;

***NEW PIR***;
IF 0<=INDFMPIR< 1.00 THEN NPIR=1;
ELSE IF 1.00<=INDFMPIR< 2.00 THEN NPIR=2;
ELSE IF 2.00<=INDFMPIR< 4.00 THEN NPIR=3;
ELSE IF 4.00<=INDFMPIR< 5.00 THEN NPIR=4;
ELSE IF 5.00<=INDFMPIR THEN NPIR=5;
ELSE IF INDFMPIR=. THEN NPIR=6;

RENAME INDFMPIR=DMPPIR;

***NATIVITY STATUS: 1=US BORN 2: FOREIGN BORN***;
IF DMDBORN  = 1 THEN US_BORN=1;
ELSE IF DMDBORN = 2 or DMDBORN = 3 THEN US_BORN=2;
ELSE IF DMDBORN = 7 or DMDBORN = 9 or DMDBORN = . THEN US_BORN=3;

****AGE****;
RENAME RIDAGEYR=HSAGEIR;

****SEX****;
RENAME RIAGENDR=HSSEX;

****RACE/ETHNICITY****;
*RIDRETH2 codes are: 1=NH WHITE, 2=NH BLACK, 3=MEX AM, 4=OTHER-INCLUDING MULTIRACIAL, 5=OTHER HISPANIC**;
*Use RIDRETH1 instead, with: 3=NH WHITE, 4=NH BLACK, 1=MEX AM, 5=OTHER-INCLUDING MULTIRACIAL, 2=OTHER HISPANIC**;

***Recode for paper ***;
IF RIDRETH1 = 1 THEN DMARETHN = 3;
ELSE IF RIDRETH1 = 2 THEN DMARETHN = 5;
ELSE IF RIDRETH1 = 3 THEN DMARETHN = 1;
ELSE IF RIDRETH1 = 4 THEN DMARETHN = 2;
ELSE IF RIDRETH1 = 5 THEN DMARETHN = 4;

***HP2020 template***;
IF DMARETHN = 1 THEN DMARETHN2020 = 1;
ELSE IF DMARETHN = 2 THEN DMARETHN2020 = 2;
ELSE IF DMARETHN = 3 THEN DMARETHN2020 = 3;
ELSE IF DMARETHN IN (4,5) THEN DMARETHN2020=4;

****HP2020-consistent AGE CATEGORIES ***;
IF RIDAGEYR >=20 THEN DO;
IF 20<=RIDAGEYR<=34 THEN AGEGRPN=1;
ELSE IF 35<=RIDAGEYR<=44 THEN AGEGRPN=2;
ELSE IF 45<=RIDAGEYR<=54 THEN AGEGRPN=3;
ELSE IF 55<=RIDAGEYR<=64 THEN AGEGRPN=4;
ELSE IF 65<=RIDAGEYR<=74 THEN AGEGRPN=5;
ELSE IF RIDAGEYR>=75 THEN AGEGRPN=6;
END;

****COMPLETE DENTAL EXAM: 1=DENTAL EXAM 2=NO EXAM***; /*not needed for OH-5 denominator */
*if OHASCST3=1 then DEEXAM=1;
*else if OHASCST3=2 then DEEXAM=2;
*RENAME OHASCST3=DEPEXFLG;

****COMPLETE PERIO EXAM: 1=DENTAL EXAM 2=NO EXAM***; /*not needed for OH-5 denominator */
*if OHASCST4=1 then COMPLETE=1;
*else if OHASCST4=2 then COMPLETE=2;
*RENAME OHASCST4=DEPLAFLG;

YEAR =2; /* legacy value */

RUN;

*DATA C.NH0104_rev;
*set NH0104_rev;
*run;

/********* Frequency check ********/
proc freq data=NH0104_rev;
where (HSAGEIR >=45 & HSAGEIR<=74);
tables HSSEX DMARETHN EDUC NEDUC NPIR US_BORN HP2020mod HP2020sev HP2020perio tprox permcount;
title1  "Codebook for OH-5 used in Talih (2012)";
title2  "Correct denominator (using tprox >=2 instead of tprox >=1)";
footnote1  "HSSEX: 1=Male, 2=Female";
footnote2  "DMARETHN: 1=NH-White, 2=NH-Black, 3=Mex. Am., 4=Other Race-Incl. Multi-Racial, 5=Other Hisp.";
footnote3  "DMARETHN2020: 1=NH-White, 2=NH-Black, 3=Mex. Am., 4=Other";
footnote4  "EDUC: 1=<HS, 2=HS grad., 3=>HS, 4=N/A";
footnote5  "NEDUC: 1=<HS, 2=HS grad., 3=Some college or AA degree, 4=College grad. or above, 5=N/A";
footnote6  "NPIR: 1=PIR <100, 2=PIR 100-199, 3=PIR 200-399, 4=PIR 400-499, 5=PIR 500+, 6=N/A";
footnote7  "US_BORN: 1=Born in US, 2=Born outside US, 3=N/A";
footnote8  "HP2020mod: Moderate perio.; HP2020sev: Severe perio.; HP2020perio: Moderate or severe perio.";
footnote9  "tprox: Number of permanent teeth with valid perio measurements on two inter-proximal sites";
footnote10 "permcount: Number of permanent teeth present";
run;

/********* Frequencies (SUDAAN) to check against the published HP2020 baseline prevalence *****/

PROC SORT DATA=NH0104_rev;
BY SDPSTRA6 SDPPSU6;
RUN;

proc descript data=NH0104_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (HSAGEIR >=45 & HSAGEIR<=74);
CLASS HSSEX DMARETHN DMARETHN2020 EDUC NEDUC NPIR US_BORN;
VAR  HP2020mod HP2020sev HP2020perio;
print / wsumfmt=F12.2 meanfmt=F10.3  semeanfmt=F10.5 
 lowmeanfmt=F10.3 upmeanfmt=F10.3 style=NCHS;
title1  "Codebook for OH-5 used in Talih (2012)";
title2  "Correct denominator (using tprox >=2 instead of tprox >=1)";
footnote1  "HSSEX: 1=Male, 2=Female";
footnote2  "DMARETHN: 1=NH-White, 2=NH-Black, 3=Mex. Am., 4=Other Race-Incl. Multi-Racial, 5=Other Hisp.";
footnote3  "DMARETHN2020: 1=NH-White, 2=NH-Black, 3=Mex. Am., 4=Other";
footnote4  "EDUC: 1=<HS, 2=HS grad., 3=>HS, 4=N/A";
footnote5  "NEDUC: 1=<HS, 2=HS grad., 3=Some college or AA degree, 4=College grad. or above, 5=N/A";
footnote6  "NPIR: 1=PIR <100, 2=PIR 100-199, 3=PIR 200-399, 4=PIR 400-499, 5=PIR 500+, 6=N/A";
footnote7  "US_BORN: 1=Born in US, 2=Born outside US, 3=N/A";
footnote8  "HP2020mod: Moderate perio.; HP2020sev: Severe perio.; HP2020perio: Moderate or severe perio.";
run;


/*
proc descript data=NH0104_rev
filetype = sas  design = wr;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (HSAGEIR >=45 & HSAGEIR<=74 & HP2020perio = 1); 
CLASS HSSEX DMARETHN DMARETHN2020 EDUC NEDUC NPIR US_BORN;
VAR  HP2020cal4 HP2020cal6;
print / wsumfmt=F12.2 meanfmt=F10.3  semeanfmt=F10.5 
 lowmeanfmt=F10.3 upmeanfmt=F10.3 style=NCHS;
run;
*/
