/* SAS syntax for HP2020 objective HDS-8 */
/* Reference: Talih, M. (2012). A reference-invariant health disparity index based on Renyi divergence. Annals of Applied Statistics.*/
/* Prepared by Makram Talih at NCHS */
/* December 2012 */

LIBNAME C '\\***\cholestdata\SRI_PAPER'; *set to desired libray location;

DATA NH0508_rev;
set C.nhanes0508;

****CREATING 4-YEAR WEIGHT VARIABLES (correct way of combining only two surveys?)**;
IF SURVEY= 5 THEN DO;
	WTINT22YR=(0.5*WTINT2YR);
	WTMEC22YR=(0.5*WTMEC2YR);
END;

IF SURVEY= 7 THEN DO;
	WTINT22YR=(0.5*WTINT2YR);
	WTMEC22YR=(0.5*WTMEC2YR);
END;

/* rename to keep compatibility with NHANES III nomenclature */

RENAME WTMEC22YR=WTPFEX6; ***weights***;
RENAME SDMVSTRA=SDPSTRA6; ***STRATA***;
RENAME SDMVPSU=SDPPSU6;   ***PSU***;

**Sociodemographic variables**;

*NEW EDUCATION CATEGORIES: 1=less than high school, 2=high school graduate, 3=some college or AA, 4 = college graduate or above, 5=missing;
IF DMDEDUC2 IN (1,2) THEN NEDUC=1;
ELSE IF DMDEDUC2=3 THEN NEDUC=2;
ELSE IF DMDEDUC2=4 THEN NEDUC=3;
ELSE IF DMDEDUC2=5 THEN NEDUC=4;
ELSE IF DMDEDUC2 IN (7,9) or DMDEDUC2=. THEN NEDUC=5; **MISSING**;

***Family Income: <= $19,999, $20,000-$44,999, $45,000+ AND MISSING;**;
IF SURVEY= 5 THEN DO;
	IF 1<= INDFMINC<=4  THEN INC3=1;
	ELSE IF 5<=INDFMINC<=7 THEN INC3=2;
	ELSE IF 8<=INDFMINC<=11 THEN INC3=3;
	ELSE IF 12<=INDFMINC<=99 OR INDFMINC=. THEN INC3=4;
END;

IF SURVEY= 7 THEN DO;
	IF 1<= INDFMIN2<=4  THEN INC3=1;
	ELSE IF 5<=INDFMIN2<=7 THEN INC3=2;
	ELSE IF 8<=INDFMIN2<=10 OR 14<=INDFMIN2<=15 THEN INC3=3;
	ELSE IF 12<=INDFMIN2<=13 OR 77<=INDFMIN2<=99 OR INDFMIN2=. THEN INC3=4;
END;

**HOUSEHOLD INCOME: <= $19,999, $20,000-$44,999, $45,000+ AND MISSING;**;
IF SURVEY= 5 THEN DO;
	IF 1<= INDHHINC<=4 THEN HINC3=1;
	ELSE IF 5<=INDHHINC<=7 THEN HINC3=2;
	ELSE IF 8<=INDHHINC<=11 THEN HINC3=3;
	ELSE IF 12<=INDHHINC<=99 OR INDHHINC=. THEN HINC3=4;
END;

IF SURVEY= 7 THEN DO;
	IF 1<= INDHHIN2 <=4  THEN HINC3=1;
	ELSE IF 5<=INDHHIN2<=7 THEN HINC3=2;
	ELSE IF 8<=INDHHIN2<=10 OR 14<=INDHHIN2<=15 THEN HINC3=3;
	ELSE IF 12<=INDHHIN2<=13 OR 77<=INDHHIN2<=99 OR INDHHIN2=. THEN HINC3=4;
END;

***PIR****;
IF 0<=INDFMPIR<=1.850 THEN PIR=1;
ELSE IF 1.86<=INDFMPIR<=3.50 THEN PIR=2;
ELSE IF 3.51<=INDFMPIR<=5 THEN PIR=3;
ELSE IF INDFMPIR=. THEN PIR=4;

***NEW PIR***;
IF 0<=INDFMPIR< 1.00 THEN NPIR=1;
ELSE IF 1.00<=INDFMPIR< 2.00 THEN NPIR=2;
ELSE IF 2.00<=INDFMPIR< 4.00 THEN NPIR=3;
ELSE IF 4.00<=INDFMPIR< 5.00 THEN NPIR=4;
ELSE IF 5.00<=INDFMPIR THEN NPIR=5;
ELSE IF INDFMPIR=. THEN NPIR=6;

RENAME INDFMPIR=DMPPIR;

***NATIVITY STATUS: 1=US BORN 2: FOREIGN BORN***;
IF SURVEY= 5 THEN DO;
	HFA6XCR=DMDBORN;
	IF DMDBORN  =1 THEN US_BORN=1;
	ELSE IF DMDBORN IN (2,3) THEN US_BORN=2;
	ELSE IF DMDBORN = 7 OR DMDBORN = . THEN US_BORN=3;
END;

IF SURVEY= 7 THEN DO;
	HFA6XCR=DMDBORN2;
	IF DMDBORN2  =1 THEN US_BORN=1;
	ELSE IF DMDBORN2 IN (2,4,5) THEN US_BORN=2;
	ELSE IF DMDBORN2 IN (7,9) OR DMDBORN2 = . THEN US_BORN=3;
END;

****AGE****;
RENAME RIDAGEYR=HSAGEIR;

****SEX****;
RENAME RIAGENDR=HSSEX;

****RACE/ETHNICITY****;
*RENAME RIDRETH1=DMARETHN; **1=MEX AM, 2=OTHER HISPANIC, 3=NH WHITE, 4=NH BLACK,5=OTHER-INCLUDING MULTIRACIAL **;

***Rearrange for ease of reference***;
IF RIDRETH1 = 1 THEN DMARETHN = 3;
ELSE IF RIDRETH1 = 3 THEN DMARETHN = 1;
ELSE IF RIDRETH1 = 4 THEN DMARETHN = 2;
ELSE IF RIDRETH1 = 2 THEN DMARETHN = 4;
ELSE IF RIDRETH1 = 5 THEN DMARETHN = 5;

***HP2020 template***;
IF RIDRETH1 = 1 THEN DMARETHN2020 = 3;
ELSE IF RIDRETH1 = 3 THEN DMARETHN2020 = 1;
ELSE IF RIDRETH1 = 4 THEN DMARETHN2020 = 2;
ELSE IF RIDRETH1 IN (2,5) THEN DMARETHN2020=4;

****HP2020-consistent AGE CATEGORIES ***;
IF RIDAGEYR >=20 THEN DO;
	IF 20<=RIDAGEYR<=29 THEN AGEGRPN=1;
	ELSE IF 30<=RIDAGEYR<=39 THEN AGEGRPN=2;
	ELSE IF 40<=RIDAGEYR<=49 THEN AGEGRPN=3;
	ELSE IF 50<=RIDAGEYR<=59 THEN AGEGRPN=4;
	ELSE IF 60<=RIDAGEYR<=69 THEN AGEGRPN=5;
	ELSE IF 70<=RIDAGEYR<=79 THEN AGEGRPN=6;
	ELSE IF RIDAGEYR>=80 THEN AGEGRPN=7;
END;

*** education is for 25+ years only ***;
IF RIDAGEYR >=25 THEN DO;
	IF 25<=RIDAGEYR<=29 THEN AGEGRPN2=1;
	ELSE IF 30<=RIDAGEYR<=39 THEN AGEGRPN2=2;
	ELSE IF 40<=RIDAGEYR<=49 THEN AGEGRPN2=3;
	ELSE IF 50<=RIDAGEYR<=59 THEN AGEGRPN2=4;
	ELSE IF 60<=RIDAGEYR<=69 THEN AGEGRPN2=5;
	ELSE IF 70<=RIDAGEYR<=79 THEN AGEGRPN2=6;
	ELSE IF RIDAGEYR>=80 THEN AGEGRPN2=7;
END;

IF RIDAGEYR >=20 THEN DO;
	IF 20<=RIDAGEYR<=24 THEN AGEGRPN3=1;
	ELSE IF 25<=RIDAGEYR<=44 THEN AGEGRPN3=2;
	ELSE IF 45<=RIDAGEYR<=54 THEN AGEGRPN3=3;
	ELSE IF 55<=RIDAGEYR<=64 THEN AGEGRPN3=4;
	ELSE IF 65<=RIDAGEYR<=74 THEN AGEGRPN3=5;
	ELSE IF 75<=RIDAGEYR<=79 THEN AGEGRPN3=6;
	ELSE IF RIDAGEYR>=80 THEN AGEGRPN3=7;
END;

IF RIDAGEYR >=20 THEN DO;
	IF 20<=RIDAGEYR<=44 THEN AGEGRPN4=1;
	ELSE IF 45<=RIDAGEYR<=64 THEN AGEGRPN4=2;
	ELSE IF RIDAGEYR>=65 THEN AGEGRPN4=3;
END;

YEAR = 1; /* legacy value */

RUN;

DATA C.NH0508_rev;
set NH0508_rev;
run;

/********* Frequency check ********/
*proc freq data=C.NH0508_rev;
*where (HSAGEIR >=20);
*tables AGEGRPN AGEGRPN2 HSSEX DMARETHN NEDUC INC3 NPIR US_BORN LBXTC;
*run;

/********* Frequencies (SUDAAN) to check against the published HP2020 baseline for objective HDS-8 *****/
/**** need to age-adjust ****/

PROC SORT DATA=C.NH0508_rev;
BY SDPSTRA6 SDPPSU6;
RUN;

proc descript data=C.NH0508_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (HSAGEIR >=20);
subgroup  AGEGRPN HSSEX DMARETHN DMARETHN2020 INC3 NPIR US_BORN;
levels         7      2        5    4            4    6   3; 
VAR  LBXTC;
stdvar AGEGRPN;
stdwgt 0.183707 0.212873 0.215904 0.155892 0.102446 0.082410 0.046767;
print / wsumfmt=F12.2 meanfmt=F10.1  semeanfmt=F10.3 
 lowmeanfmt=F10.1 upmeanfmt=F10.1 style=NCHS;
rtitle "Age-standardized mean total blood cholesterol levels among adults aged 20 years and over: NHANES 2005-2008";
rfootnote "Age adjusted (by the direct method) to the year 2000 U.S. population using the age groups 20-29, 30-39, 40-49, 50-59, 60-69, 70-79, and 80+"; 
run;


proc descript data=C.NH0508_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (HSAGEIR >=25);
subgroup  AGEGRPN2 NEDUC;
levels         7     5; 
VAR  LBXTC;
stdvar AGEGRPN2;
stdwgt 0.099790 0.234757 0.238100 0.171918 0.112978 0.090882 0.051575;
print / wsumfmt=F12.2 meanfmt=F10.1  semeanfmt=F10.3 
 lowmeanfmt=F10.1 upmeanfmt=f10.1 style=NCHS;
rtitle " Age-standardized mean total blood cholesterol levels among adults aged 25 years and over: NHANES 2005-2008";
rfootnote "Age adjusted by the direct method to the year 2000 U.S. population using the age groups 25-29, 30-39, 40-49, 50-59, 60-69, 70-79, and 80+"; 
run;


proc descript data=C.NH0508_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (20<= HSAGEIR & HSAGEIR <= 24);
CLASS  HSSEX DMARETHN DMARETHN2020 NPIR US_BORN; 
VAR  LBXTC;
print / wsumfmt=F12.2 meanfmt=F10.1  semeanfmt=F10.3 
 lowmeanfmt=F10.1 upmeanfmt=F10.1 style=NCHS;
run;

proc descript data=C.NH0508_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (25<= HSAGEIR & HSAGEIR <= 44);
CLASS  HSSEX DMARETHN DMARETHN2020 NEDUC NPIR US_BORN; 
VAR  LBXTC;
print / wsumfmt=F12.2 meanfmt=F10.1  semeanfmt=F10.3 
 lowmeanfmt=F10.1 upmeanfmt=F10.1 style=NCHS;
run;

proc descript data=C.NH0508_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (45<= HSAGEIR & HSAGEIR <= 54);
CLASS  HSSEX DMARETHN DMARETHN2020 NEDUC NPIR US_BORN; 
VAR  LBXTC;
print / wsumfmt=F12.2 meanfmt=F10.1  semeanfmt=F10.3 
 lowmeanfmt=F10.1 upmeanfmt=F10.1 style=NCHS;
run;

proc descript data=C.NH0508_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (55<= HSAGEIR & HSAGEIR <= 64);
CLASS  HSSEX DMARETHN DMARETHN2020 NEDUC NPIR US_BORN; 
VAR  LBXTC;
print / wsumfmt=F12.2 meanfmt=F10.1  semeanfmt=F10.3 
 lowmeanfmt=F10.1 upmeanfmt=F10.1 style=NCHS;
run;

proc descript data=C.NH0508_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (65<= HSAGEIR & HSAGEIR <= 74);
CLASS  HSSEX DMARETHN DMARETHN2020 NEDUC NPIR US_BORN; 
VAR  LBXTC;
print / wsumfmt=F12.2 meanfmt=F10.1  semeanfmt=F10.3 
 lowmeanfmt=F10.1 upmeanfmt=F10.1 style=NCHS;
run;

proc descript data=C.NH0508_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (75<= HSAGEIR & HSAGEIR <= 79);
CLASS  HSSEX DMARETHN DMARETHN2020 NEDUC NPIR US_BORN; 
VAR  LBXTC;
print / wsumfmt=F12.2 meanfmt=F10.1  semeanfmt=F10.3 
 lowmeanfmt=F10.1 upmeanfmt=F10.1 style=NCHS;
run;

proc descript data=C.NH0508_rev
filetype = sas  design = wr   ;
nest SDPSTRA6 SDPPSU6/missunit;
weight WTPFEX6;
subpopn  (80<= HSAGEIR);
CLASS  HSSEX DMARETHN DMARETHN2020 NEDUC NPIR US_BORN; 
VAR  LBXTC;
print / wsumfmt=F12.2 meanfmt=F10.1  semeanfmt=F10.3 
 lowmeanfmt=F10.1 upmeanfmt=F10.1 style=NCHS;
run;

