########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

########################################################################
# Code is backward compatible with that used in:
#
# Borrell, L.N., M. Talih (2012). 
# Examining periodontal disease disparities among U.S. adults 20 years of age and older: 
# NHANES III (1988-1994) and NHANES 1999-2004. 
# Public Health Reports, 127, pp.497-506.
#
# Borrell, L.N., M. Talih (2011). 
# A Symmetrized Theil index measure of health disparities: 
# An example using dental caries in U.S. children and adolescents. 
# Statistics in Medicine, 30 (3), pp. 277-90. 
# First published online 5 November 2010. 
# DOI: 10.1002/sim.4114.
#
#########################################################################

###############################
# Last modified 11 December 2012
###############################


###########################
## Within SUBGRP.VAR variable (passed from parent call)

#############################################################################
## Output formatting function for response variable 'resp.var' when positive:

##############
## No grouping

if (out.file != "") {
  cat(paste(SUBGRP.VAR, "level", sep="."), "\t", "grouping", "\t", "type", "\t", "alpha", "\t", "which", "\t", "index", "\t", "proportion", "\t", "BJ.se", "\t", "BJ.lo", "\t", "BJ.hi", "\t", "BRR.se", "\t", "BRR.lo", "\t", "BRR.hi", "\t", "BS.se", "\t", "BS.lo", "\t", "BS.hi", "\n", file=out.file, append=FALSE)
}

for (sub.var in levels(NH3.sub[, SUBGRP.VAR])) {
  cat("\n\n\n\t", "... WITHIN", SUBGRP.VAR, "=", sub.var, "\n")
  
  print.means = PRINT.MEANS
  print.diff = PRINT.DIFF
  n.suppress = N.SUPPRESS
  
  for (type in index.type) {
    for (alpha in alpha.range) {  
  
      if (out.file != "") {
        cat(sub.var, "\t", "ALL", "\t", file=out.file, append=TRUE)
      }
      
      theil.decomposition.out(type = type,
                            alpha = alpha, 
                            data = NULL,
                            w.boot.data = w.boot.sub,
                            w.BRR.data = w.BRR.sub,
                            fay.rho = FAY.RHO,
                            subset = unhealthy.sub & !is.na(NH3.sub[, SUBGRP.VAR]) & NH3.sub[, SUBGRP.VAR] == sub.var,
                            response = resp.var,
                            w.var = "",
                            svobj = subset(unhealthy.str, !is.na(unhealthy.str$variables[, SUBGRP.VAR]) & unhealthy.str$variables[, SUBGRP.VAR] == sub.var),
                            grouping = NULL,
                            na.rm=TRUE,
                            bw="nrd",
                            kernel="gaussian",
                            from=0,
                            digits=DIGITS,
                            print.means = print.means,
                            print.diff = print.diff,
                            n.suppress = n.suppress,
                            compute.MC = FALSE,
                            compute.BJ = TRUE, 
                            out.file=out.file)
      print.means = FALSE
    }
  }
}
rm(type, alpha, sub.var, print.means, print.diff, n.suppress)

#################################
# Last modified 11 December 2012. MT.
#################################
