########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

########################################################################
# Code is backward compatible with that used in:
#
# Borrell, L.N., M. Talih (2012). 
# Examining periodontal disease disparities among U.S. adults 20 years of age and older: 
# NHANES III (1988-1994) and NHANES 1999-2004. 
# Public Health Reports, 127, pp.497-506.
#
# Borrell, L.N., M. Talih (2011). 
# A Symmetrized Theil index measure of health disparities: 
# An example using dental caries in U.S. children and adolescents. 
# Statistics in Medicine, 30 (3), pp. 277-90. 
# First published online 5 November 2010. 
# DOI: 10.1002/sim.4114.
#
#########################################################################

###############################
# Last modified 11 December 2012
###############################


#############################################################################
## Output formatting function for response variable 'resp.var' when specified:

##############
## No grouping

if (out.file != "") {
  cat("Pop. level", "\t", "grouping", "\t", "type", "\t", "alpha", "\t", "which", "\t", "index", "\t", "proportion", "\t", "BJ.se", "\t", "BJ.lo", "\t", "BJ.hi", "\t", "BRR.se", "\t", "BRR.lo", "\t", "BRR.hi", "\t", "BS.se", "\t", "BS.lo", "\t", "BS.hi", "\n", file=out.file, append=FALSE)
}

# flag for print out of the mean estimates, see for loop below.
print.means = PRINT.MEANS
print.diff = PRINT.DIFF
n.suppress = N.SUPPRESS

for (type in index.type) {
  for (alpha in alpha.range) {

    if (out.file != "") {
      cat("ALL", "\t", "ALL", "\t", file=out.file, append=TRUE)
    }
      
    theil.decomposition.out(type = type,                # String indicating index to work with
                          alpha = alpha,                # Inequality aversion parameter for Renyi family of indices
                          data = NULL,                  # 'data' must be supplied if calling with a NULL 'svobj'
                          w.boot.data = w.boot.sub,     # Rescaled bootstrap method if desired
                          w.BRR.data = w.BRR.sub,       # BRR method if desired
                          fay.rho = FAY.RHO,            # Value of Fay's adjustment for BRR method
                          subset = unhealthy.sub,       # 'subset' is used for 'data' and for 'w.boot.data' & 'w.BRR.data'
                          response = resp.var,          # label of the response variable
                          w.var = "",                   # 'w.var' only needed if calling with a NULL 'svobj'
                          svobj = unhealthy.str,        # svydesign object. dim(svobj) should match sum(subset).
                          grouping = NULL,              # current implementation only works with at most one grouping variable
                          na.rm=TRUE,                   # whether or not to remove NA in response variable
                          bw="nrd",                     # bandwidth method in density() for Martinez-Camblor type estimation
                          kernel="gaussian",            # kernel type in density() for Martinez-Camblor type estimation
                          from=0,                       # left-most boundary for kernel density estimate
                          digits=DIGITS,                # significant digits to print
                          print.means = print.means,    
                          print.diff = print.diff,
                          n.suppress = n.suppress,
                          compute.MC = FALSE,           # compute Martinez-Camblor type standard errors
                          compute.BJ = TRUE,            # Compute Biewen-Jenkins style Taylor linearization SE's
                          out.file=out.file)

    print.means = FALSE   # suppress printing table of means the second time through      
  }
}
rm(type, alpha, print.means, print.diff, n.suppress)

#################################
# Last modified 11 December 2012. MT.
#################################

