########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

########################################################################
# Code is backward compatible with that used in:
#
# Borrell, L.N., M. Talih (2012). 
# Examining periodontal disease disparities among U.S. adults 20 years of age and older: 
# NHANES III (1988-1994) and NHANES 1999-2004. 
# Public Health Reports, 127, pp.497-506.
#
# Borrell, L.N., M. Talih (2011). 
# A Symmetrized Theil index measure of health disparities: 
# An example using dental caries in U.S. children and adolescents. 
# Statistics in Medicine, 30 (3), pp. 277-90. 
# First published online 5 November 2010. 
# DOI: 10.1002/sim.4114.
#
#########################################################################

###############################
# Last modified 11 December 2012
###############################


###########################################################
## Output formatting function for binary response variable:

if (out.file != "") {
  cat("grouping", "\t", "type", "\t", "alpha", "\t", "index", "\t", "BJ.se", "\t", "BJ.lo", "\t", "BJ.hi", "\t", "BRR.se", "\t", "BRR.lo", "\t", "BRR.hi", "\t", "BS.se", "\t", "BS.lo", "\t", "BS.hi", "\n", file=out.file, append=FALSE)
}

##############################################
## Initialize results storage for BRR and bootstrap runs:

if (STORE.RUNS) {

  RUNS.bin = vector("list", length(grp.list)*length(index.type)*length(alpha.range))

  if (!is.null(w.BRR.sub) & !is.null(w.boot.sub)) {
    init = list(grp.var="", type="", alpha=NA, ind=NA, BRR=vector("numeric", ncol(w.BRR.sub)), boot=vector("numeric", ncol(w.boot.sub)))
  } else if (!is.null(w.BRR.sub) & is.null(w.boot.sub)) {
    init = list(grp.var="", type="", alpha=NA, ind=NA, BRR=vector("numeric", ncol(w.BRR.sub)), boot=NULL)
  } else if (is.null(w.BRR.sub) & !is.null(w.boot.sub)) {
    init = list(grp.var="", type="", alpha=NA, ind=NA, BRR=NULL, boot=vector("numeric", ncol(w.boot.sub)))
  } else {
    init = list(grp.var="", type="", alpha=NA, ind=NA, BRR=NULL, boot=NULL)
  }

  for (u in 1:length(RUNS.bin)) {
    RUNS.bin[[u]] = init
  }

  cntr = 1

}

for (grp.var in grp.list) {

  # flag for print out of the prevalence estimates, see for loop below.
  print.prev = TRUE 

  cat("\n\n\n\t DECOMPOSITION BY", grp.var, "\n")
  
    for (type in index.type) {
      for (alpha in alpha.range) {
    
	if (out.file != "") {
      	  cat(grp.var, "\t", file=out.file, append=TRUE)
    	}

        init = theil.decomposition.bin(type = type,          # String indicating index to work with
                            alpha = alpha,            # Inequality aversion parameter for Renyi family of indices
                            grp.var = grp.var,        # current implementation only works with one grouping variable
                            bin.var = bin.var,        # 'bin.var' must be supplied
                            svobj = NH3.sub.str,      # 'svobj' is a 'svydesign' object (Required for BJ.se method. Set to NULL if BJ.se not needed.)
                            statistic = "adjWald",    # desired design-based test in contingency table
                            w.var = "",               # 'w.var' only needed if calling with a NULL 'svobj'
                            data = NULL,              # 'data' must be supplied if calling with a NULL 'svobj'
                            response.grp = NULL,      # One of 'response.grp' or 'bin.var' must be supplied.
                                                      # Use of 'bin.var' is strongly recommended!
                                                      # (due to properly subsetting a global logical condition...)
                            w.boot.data = w.boot.sub, # Rescaled bootstrap method if desired
                            w.BRR.data = w.BRR.sub,   # BRR method if desired
                            fay.rho = FAY.RHO,        # Value of Fay's adjustment for BRR method
                            na.rm = TRUE,             # whether or not to remove NA in response variable
                            digits = DIGITS,          # significant digits to print
                            out.file=out.file,
                            print.prev=print.prev,    # suppress printing table of frequencies the second time through
                            store.runs=STORE.RUNS)    # whether to store BRR and bootstrap runs for later access.

        # print out prevalence and contingency table first time around only
        print.prev = FALSE

        if (STORE.RUNS) {
          # save runs for later use
          RUNS.bin[[cntr]]$grp.var = grp.var
          RUNS.bin[[cntr]]$type = init$type
          RUNS.bin[[cntr]]$alpha = init$alpha
          RUNS.bin[[cntr]]$ind = init$ind
          RUNS.bin[[cntr]]$BRR = init$BRR
          RUNS.bin[[cntr]]$boot = init$boot
          cntr = cntr + 1
        }        
      }
    }
}
rm(grp.var, type, alpha, print.prev, init)

#################################
# Last modified 11 December 2012. MT.
#################################
