########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

########################################
# Last modified: 11 December 2012. MT. #
########################################

##################################
## Code for generating Figure 2 ##
##################################

setwd("C:/***/pubperio/nhanes0104/output-files") # set to desired working directory
load("C:\\***\\pubperio\\nhanes0104\\output-files\\9Aug2012.RData") # load saved workspace from desired directory

titles = c("Sex", "Race/Ethnicity (excl. Other)", "Race/Ethnicity (incl. Other)", "Educational attainment", "Family income (% FPL)", "Country of birth")
labs =  c("HSSEX", "DMARETHN2020", "DMARETHN", "NEDUC", "NPIR", "US_BORN")
names(titles) = labs

AT = c(0.5, 1, 2, 4, 8, 16, 32, 64, 128)
JIT = c(0.04, 0.08, 0.14, 0.3, 0.7, 1.3, 2.5, 5, 10)
names(JIT) = as.character(AT)

RUNS.bin.SRPW = vector("list", length(RUNS.bin)/2)
RUNS.bin.SREW = vector("list", length(RUNS.bin)/2)

cntr1=1
cntr2=1
for (u in 1:length(RUNS.bin)) {
  if (is.element(RUNS.bin[[u]]$type, c("SRPW", "S")) & is.element(RUNS.bin[[u]]$alpha, AT)) {
    RUNS.bin.SRPW[[cntr1]] = RUNS.bin[[u]]
    cntr1=cntr1+1
  }
  if (is.element(RUNS.bin[[u]]$type, c("SREW", "RS")) & is.element(RUNS.bin[[u]]$alpha, AT)) {
    RUNS.bin.SREW[[cntr2]] = RUNS.bin[[u]]
    cntr2=cntr2+1
  }
}

postscript(file = "perio-sample-dist.eps", width=11, height=8.5, horizontal=T, family="Palatino", paper="letter")

par(mfrow=c(2,3))

for (g in labs) {
  ADD=FALSE
  MAIN=titles[g]
  YLAB="Standardized between-group SRI (percent)"
  XLAB="Parameter value"
  for (u in 1:length(RUNS.bin.SRPW)) {
    COL=4
    if (!is.null(RUNS.bin.SRPW[[u]])) {
      if (RUNS.bin.SRPW[[u]]$grp.var == g) {
        boxplot(1-exp(-RUNS.bin.SRPW[[u]]$alpha*RUNS.bin.SRPW[[u]]$boot), log="x", xlim=c(0.5,128), ylim=c(0, 75/100), ylab=YLAB, xlab=XLAB, axes=F, bty="n", outpch="*", boxwex=0.25, col=COL, border=COL, medcol="white", medlwd=1, whisklty=1, whisklwd=0.5, staplelwd=0.5, at=RUNS.bin.SRPW[[u]]$alpha+JIT[as.character(RUNS.bin.SRPW[[u]]$alpha)], add=ADD, main=MAIN)   
        ADD=TRUE
        MAIN=NULL
        YLAB=NULL
        XLAB=NULL
      }
    }
    COL=2
    if (!is.null(RUNS.bin.SREW[[u]])) {
      if (RUNS.bin.SREW[[u]]$grp.var == g) {
        boxplot(1-exp(-RUNS.bin.SREW[[u]]$alpha*RUNS.bin.SREW[[u]]$boot), log="x", xlim=c(0.5,128), ylim=c(0, 75/100), ylab=YLAB, xlab=XLAB, axes=F, bty="n", outpch="*", boxwex=0.25, col=COL, border=COL, medcol="white", medlwd=1, whisklty=1, whisklwd=0.5, staplelwd=0.5, at=RUNS.bin.SREW[[u]]$alpha-JIT[as.character(RUNS.bin.SREW[[u]]$alpha)], add=ADD, main=MAIN)   
      }
    }
  }
  axis(2, at=c(0, 0.10, 0.20, 0.30, 0.40, 0.50, 0.60, 0.70), labels=c(0, 10, 20, 30, 40, 50, 60, 70))
  axis(1, at=AT, labels=AT)

  if (g == "HSSEX") {
						text(1.5, 0.60, "Relative shares (%) of...", pos=4, cex=0.85)
						text(1.5, 0.57, "...disease", pos=4, cex=0.85);	  text(4.5, 0.57,  "...population (pop.)", pos=4, cex=0.85)
    text(1.5, 0.54, "Male", pos=2, cex=0.85); 	text(1.5, 0.54, "62.2", pos=4, cex=0.85); text(4.5, 0.54, "48.8", pos=4, cex=0.85)
    text(1.5, 0.51, "Female", pos=2, cex=0.85); text(1.5, 0.51, "37.8", pos=4, cex=0.85); text(4.5, 0.51, "51.2", pos=4, cex=0.85) 
    legend(x="topleft", legend=c("Population-weighted SRI", "Equally-weighted SRI"), fill=c(4,2), border = c(4,2), bty="n") 
  }
  else if (g == "DMARETHN2020") {
								text(3.5, 0.60, "Relative shares (%) of...", pos=4, cex=0.85)
								text(3.5, 0.57, "...disease", pos=4, cex=0.85);		text(10.0, 0.57,  "...pop.", pos=4, cex=0.85)
    text(3.6, 0.54, "Non-Hispanic white", pos=2, cex=0.85);	text(3.5, 0.54, "74.1", pos=4, cex=0.85); 	text(10.0, 0.54, "84.9", pos=4, cex=0.85)
    text(3.6, 0.51, "Non-Hispanic black", pos=2, cex=0.85);	text(3.5, 0.51, "18.1", pos=4, cex=0.85); 	text(10.0, 0.51, " 9.9", pos=4, cex=0.85)
    text(3.6, 0.48,  "Mexican American", pos=2, cex=0.85);	text(3.5, 0.48, " 7.8", pos=4, cex=0.85); 	text(10.0, 0.48, " 5.2", pos=4, cex=0.85)
    legend(x="topleft", legend=c("Population-weighted SRI", "Equally-weighted SRI"), fill=c(4,2), border = c(4,2), bty="n") 
  }
  else if (g == "DMARETHN") {
								text(3.5, 0.60, "Relative shares (%) of...", pos=4, cex=0.85)
								text(3.5, 0.57, "...disease", pos=4, cex=0.85);		text(10.0, 0.57,  "...pop.", pos=4, cex=0.85)
    text(3.6, 0.54, "Non-Hispanic white", pos=2, cex=0.85);	text(3.5, 0.54, "64.2", pos=4, cex=0.85); 	text(10.0, 0.54, "77.8", pos=4, cex=0.85)
    text(3.6, 0.51, "Non-Hispanic black", pos=2, cex=0.85);	text(3.5, 0.51, "15.7", pos=4, cex=0.85); 	text(10.0, 0.51, " 9.0", pos=4, cex=0.85) 
    text(3.6, 0.48, "Mexican American", pos=2, cex=0.85);	text(3.5, 0.48, " 6.8", pos=4, cex=0.85); 	text(10.0, 0.48, " 4.8", pos=4, cex=0.85)
    text(3.6, 0.45,  "Other", pos=2, cex=0.85);	        	text(3.5, 0.45, "13.3", pos=4, cex=0.85); 	text(10.0, 0.45, " 8.4", pos=4, cex=0.85)
    legend(x="topleft", legend=c("Population-weighted SRI", "Equally-weighted SRI"), fill=c(4,2), border = c(4,2), bty="n") 
  }
  else if (g == "NEDUC") {
								text(14, 0.18, "Relative shares (%) of...", pos=4, cex=0.85)
								text(24.0, 0.15, "...disease", pos=4, cex=0.85);	text(70.0, 0.15,  "...pop.", pos=4, cex=0.85)
    text(24.0, 0.12, "Less than HS", pos=2, cex=0.85);	 	text(24.0, 0.12, "27.5", pos=4, cex=0.85); 	text(70.0, 0.12, "13.1", pos=4, cex=0.85)
    text(24.0, 0.09, "HS graduate", pos=2, cex=0.85);	 	text(24.0, 0.09, "29.3", pos=4, cex=0.85); 	text(70.0, 0.09, "25.6", pos=4, cex=0.85) 
    text(24.0, 0.06, "Some college or AA", pos=2, cex=0.85); 	text(24.0, 0.06, "28.2", pos=4, cex=0.85); 	text(70.0, 0.06, "31.7", pos=4, cex=0.85)
    text(24.0, 0.03,  "College grad. or above", pos=2, cex=0.85); text(24.0, 0.03, "15.0", pos=4, cex=0.85); 	text(70.0, 0.03, "29.6", pos=4, cex=0.85)
    legend(x="topleft", legend=c("Population-weighted SRI", "Equally-weighted SRI"), fill=c(4,2), border = c(4,2), bty="n") 
  }
  else if (g == "NPIR") {
							text(14, 0.18, "Relative shares (%) of...", pos=4, cex=0.85)
							text(24, 0.15, "...disease", pos=4, cex=0.85);		text(70.0, 0.15,  "...pop.", pos=4, cex=0.85)	
    text(24, 0.12, "< 100", pos=2, cex=0.85);	 	text(24, 0.12, "16.1", pos=4, cex=0.85); 	text(70.0, 0.12, " 7.3", pos=4, cex=0.85)
    text(24, 0.09, "100-199", pos=2, cex=0.85);		text(24, 0.09, "25.9", pos=4, cex=0.85); 	text(70.0, 0.09, "13.7", pos=4, cex=0.85)
    text(24, 0.06, "200-399", pos=2, cex=0.85);		text(24, 0.06, "25.2", pos=4, cex=0.85); 	text(70.0, 0.06, "29.5", pos=4, cex=0.85) 
    text(24, 0.03, "400-499", pos=2, cex=0.85); 	text(24, 0.03, " 9.3", pos=4, cex=0.85); 	text(70.0, 0.03, "14.2", pos=4, cex=0.85)
    text(24, 0.00,  "500+", pos=2, cex=0.85); 	 	text(24, 0.00, "23.5", pos=4, cex=0.85); 	text(70.0, 0.00, "35.3", pos=4, cex=0.85)
    legend(x="topleft", legend=c("Population-weighted SRI", "Equally-weighted SRI"), fill=c(4,2), border = c(4,2), bty="n") 
  }
  if (g == "US_BORN") {
							text(1.5, 0.60, "Relative shares (%) of...", pos=4, cex=0.85)
							text(1.5, 0.57, "...disease", pos=4, cex=0.85);		text(4.5, 0.57,  "...pop.", pos=4, cex=0.85)
    text(1.65, 0.54, "U.S.", pos=2, cex=0.85); 		text(1.5, 0.54, "80.7", pos=4, cex=0.85); 	text(4.5, 0.54, "87.2", pos=4, cex=0.85)
    text(1.65, 0.51, "Outside U.S.", pos=2, cex=0.85); 	text(1.5, 0.51, "19.3", pos=4, cex=0.85); 	text(4.5, 0.51, "12.8", pos=4, cex=0.85) 
    legend(x="topleft", legend=c("Population-weighted SRI", "Equally-weighted SRI"), fill=c(4,2), border = c(4,2), bty="n") 
  }
}
dev.off()

rm(u, g, COL, ADD, MAIN, XLAB, YLAB, AT, JIT, titles, labs, cntr1, cntr2, RUNS.bin.SRPW, RUNS.bin.SREW)



########################################
# Last modified: 11 December 2012. MT. #
########################################
