########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

########################################
# Last modified: 11 December 2012. MT. #
########################################

##################################
## Code for generating Figure 3 ##
##################################

setwd("C:/***/pubperio/nhanes0104/output-files") # set to desired working directory
load("C:\\***\\pubperio\\nhanes0104\\output-files\\10Aug2012-null.RData") # load saved workspace from desired directory

titles = c("Sex", "Race/Ethnicity (excl. Other)", "Race/Ethnicity (incl. Other)", "Educational attainment", "Family income (% FPL)", "Country of birth")
labs =  c("HSSEX", "DMARETHN2020", "DMARETHN", "NEDUC", "NPIR", "US_BORN")
names(titles) = labs

AT = c(0.5, 1, 2, 4, 8, 16, 32, 64, 128)
JIT = c(0.04, 0.08, 0.14, 0.3, 0.7, 1.3, 2.5, 5, 10)
names(JIT) = as.character(AT)

RUNS.bin.SRPW = vector("list", length(RUNS.bin)/2)
RUNS.bin.SREW = vector("list", length(RUNS.bin)/2)

cntr1=1
cntr2=1
for (u in 1:length(RUNS.bin)) {
  if (is.element(RUNS.bin[[u]]$type, c("SRPW", "S")) & is.element(RUNS.bin[[u]]$alpha, AT)) {
    RUNS.bin.SRPW[[cntr1]] = RUNS.bin[[u]]
    cntr1=cntr1+1
  }
  if (is.element(RUNS.bin[[u]]$type, c("SREW", "RS")) & is.element(RUNS.bin[[u]]$alpha, AT)) {
    RUNS.bin.SREW[[cntr2]] = RUNS.bin[[u]]
    cntr2=cntr2+1
  }
}

postscript(file = "perio-sample-dist-null.eps", width=11, height=8.5, horizontal=T, family="Palatino", paper="letter")

par(mfrow=c(2,3))

for (g in c("DMARETHN2020")) {
  ADD=FALSE
  MAIN=titles[g]
  YLAB="Standardized between-group SRI (percent)"
  XLAB="Parameter value"
  for (u in 1:length(RUNS.bin.SRPW)) {
    COL="lightblue1"
    if (!is.null(RUNS.bin.SRPW[[u]])) {
      if (RUNS.bin.SRPW[[u]]$grp.var == g) {
        boxplot(1-exp(-RUNS.bin.SRPW[[u]]$alpha*RUNS.bin.SRPW[[u]]$boot), log="x", xlim=c(0.5,128), ylim=c(0, 75/100), ylab=YLAB, xlab=XLAB, axes=F, bty="n", outpch=NA, boxwex=0.25, col=COL, border=COL, medcol="white", medlwd=1, whisklty=1, whisklwd=0.5, staplelwd=0.5, at=RUNS.bin.SRPW[[u]]$alpha+JIT[as.character(RUNS.bin.SRPW[[u]]$alpha)], add=ADD, main=MAIN)   
        ADD=TRUE
        MAIN=NULL
        YLAB=NULL
        XLAB=NULL
      }
    }
    COL="indianred1"
    if (!is.null(RUNS.bin.SREW[[u]])) {
      if (RUNS.bin.SREW[[u]]$grp.var == g) {
        boxplot(1-exp(-RUNS.bin.SREW[[u]]$alpha*RUNS.bin.SREW[[u]]$boot), log="x", xlim=c(0.5,128), ylim=c(0, 75/100), ylab=YLAB, xlab=XLAB, axes=F, bty="n", outpch=NA, boxwex=0.25, col=COL, border=COL, medcol="white", medlwd=1, whisklty=1, whisklwd=0.5, staplelwd=0.5, at=RUNS.bin.SREW[[u]]$alpha-JIT[as.character(RUNS.bin.SREW[[u]]$alpha)], add=ADD, main=MAIN)   
      }
    }
  }
  axis(2, at=c(0, 0.10, 0.20, 0.30, 0.40, 0.50, 0.60, 0.70), labels=c(0, 10, 20, 30, 40, 50, 60, 70))
  axis(1, at=AT, labels=AT)

  if (g == "DMARETHN2020") {
								text(4.0, 0.60, "Relative shares (%)", pos=4, cex=1)
								text(3.7, 0.57, " q", pos=4, cex=0.85);		text(6.0, 0.57,  " p", pos=4, cex=0.85); 	text(9.5, 0.57, " q0", pos=4, cex=0.85)
    text(3.6, 0.54, "Non-Hispanic white", pos=2, cex=0.85);	text(3.7, 0.54, "74.1", pos=4, cex=0.85); 	text(6.0, 0.54, "84.9", pos=4, cex=0.85); 	text(9.5, 0.54, "84.8", pos=4, cex=0.85)
    text(3.6, 0.51, "Non-Hispanic black", pos=2, cex=0.85);	text(3.7, 0.51, "18.1", pos=4, cex=0.85); 	text(6.0, 0.51, " 9.9", pos=4, cex=0.85); 	text(9.5, 0.51, " 9.9", pos=4, cex=0.85)
    text(3.6, 0.48,  "Mexican American", pos=2, cex=0.85);	text(3.7, 0.48, " 7.8", pos=4, cex=0.85); 	text(6.0, 0.48, " 5.2", pos=4, cex=0.85); 	text(9.5, 0.48, " 5.3", pos=4, cex=0.85)
    legend(x="topleft", legend=c("Population-weighted SRI", "Equally-weighted SRI"), fill=c(4,2), border = c(4,2), bty="n") 
  }
}


# Superpose distributions from true run

RUNS.bin.null = RUNS.bin

load("C:\\***\\pubperio\\nhanes0104\\output-files\\9Aug2012.RData") # load saved workspace from desired directory

RUNS.bin.SRPW = vector("list", length(RUNS.bin)/2)
RUNS.bin.SREW = vector("list", length(RUNS.bin)/2)

cntr1=1
cntr2=1
for (u in 1:length(RUNS.bin)) {
  if (is.element(RUNS.bin[[u]]$type, c("SRPW", "S")) & is.element(RUNS.bin[[u]]$alpha, AT)) {
    RUNS.bin.SRPW[[cntr1]] = RUNS.bin[[u]]
    cntr1=cntr1+1
  }
  if (is.element(RUNS.bin[[u]]$type, c("SREW", "RS")) & is.element(RUNS.bin[[u]]$alpha, AT)) {
    RUNS.bin.SREW[[cntr2]] = RUNS.bin[[u]]
    cntr2=cntr2+1
  }
}

for (g in c("DMARETHN2020")) {
  ADD=TRUE
  MAIN=NULL
  YLAB=NULL
  XLAB=NULL
  for (u in 1:length(RUNS.bin.SRPW)) {
    COL="blue"
    if (!is.null(RUNS.bin.SRPW[[u]])) {
      if (RUNS.bin.SRPW[[u]]$grp.var == g) {
        boxplot(1-exp(-RUNS.bin.SRPW[[u]]$alpha*RUNS.bin.SRPW[[u]]$boot), log="x", xlim=c(0.5,128), ylim=c(0, 75/100), ylab=YLAB, xlab=XLAB, axes=F, bty="n", outpch=NA, boxwex=0.25, col=COL, border=COL, medcol="white", medlwd=1, whisklty=1, whisklwd=1.5, staplelwd=1.5, at=RUNS.bin.SRPW[[u]]$alpha+JIT[as.character(RUNS.bin.SRPW[[u]]$alpha)], add=ADD, main=MAIN)   
      }
    }
    COL="red"
    if (!is.null(RUNS.bin.SREW[[u]])) {
      if (RUNS.bin.SREW[[u]]$grp.var == g) {
        boxplot(1-exp(-RUNS.bin.SREW[[u]]$alpha*RUNS.bin.SREW[[u]]$boot), log="x", xlim=c(0.5,128), ylim=c(0, 75/100), ylab=YLAB, xlab=XLAB, axes=F, bty="n", outpch=NA, boxwex=0.25, col=COL, border=COL, medcol="white", medlwd=1, whisklty=1, whisklwd=1.5, staplelwd=1.5, at=RUNS.bin.SREW[[u]]$alpha-JIT[as.character(RUNS.bin.SREW[[u]]$alpha)], add=ADD, main=MAIN)   
      }
    }
  }
}

dev.off()

rm(u, g, COL, ADD, MAIN, XLAB, YLAB, AT, JIT, titles, labs, cntr1, cntr2, RUNS.bin.SRPW, RUNS.bin.SREW)


########################################
# Last modified: 11 December 2012. MT. #
########################################
