########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

########################################################################
# Code is backward compatible with that used in:
#
# Borrell, L.N., M. Talih (2012). 
# Examining periodontal disease disparities among U.S. adults 20 years of age and older: 
# NHANES III (1988-1994) and NHANES 1999-2004. 
# Public Health Reports, 127, pp.497-506.
#
# Borrell, L.N., M. Talih (2011). 
# A Symmetrized Theil index measure of health disparities: 
# An example using dental caries in U.S. children and adolescents. 
# Statistics in Medicine, 30 (3), pp. 277-90. 
# First published online 5 November 2010. 
# DOI: 10.1002/sim.4114.
#
#########################################################################

###############################
# Last modified 11 December 2012
###############################

###############################################################
## Modify the following headings as needed for report printout:

cat("\n\n Disparities in prevalence of moderate to severe periodontitis among adults aged 45-74 years from NHANES 2001-2004:\n")
cat("\n R Report using the symmetrized Renyi index\n\n")

cat("\n\n Reference: Talih, M. (2012).\n A reference-invariant health disparity index based on Renyi divergence.\n Paper under review.\n\n")

###############################################################
## Modify the following parameters to match desired analysis ##
###############################################################  

## Specify list of grouping variables to use in the output:
grp.list =  c("HSSEX", "DMARETHN2020", "NEDUC", "NPIR", "US_BORN", "DMARETHN")

## For analyses by population subgroup in grp.list within another grouping variable (leave as null character if not needed)
SUBGRP.LST = c("")            # eg. c("AGEGRPN", "NPIR")

## Modify report section title to match desired analysis:
SECTION.TITLE = "Periodontal disease in adults aged 45-74 years from NHANES 2001-2004"

## Modify the following heading as needed for report printout:
DISP.HEADING = "Health disparities in prevalence of moderate to severe periodontitis"

######################################################################################
## !!!!! Further global variables set in 'MasterFile' and in 'GenerateReport' !!!!! ##
######################################################################################

##########################################################################

##################################
## Do not modify the code below ##
##################################
  
cat("\n\n", SECTION.TITLE, "\n\n")

## Source setup syntax -- subset definitions are coded here...
source(paste(r03.PATH, cmn.PATH, in.PREFIX, "-setup.R", sep=""))

cat("\n ----------------------------------------------------------------------\n")
cat("\n\n\n", DISP.HEADING, "\n\n")
cat("\n ----------------------------------------------------------------------\n")

out.file = paste(r03.PATH, out.PATH, ifelse(resp.var !="", resp.var, bin.var), "-", agegrp.var, "-bin.txt", sep="") # if not needed set to ""
source(paste(r03.PATH, cmn.PATH, in.PREFIX, "-bin.R", sep=""))

if (SUBGRP.LST[1] > 0) {
  if (STORE.RUNS) {
    CNTR.RESET = TRUE
  }
  for (SUBGRP.VAR in SUBGRP.LST) {

    cat("\n -----------------------------\n")
    cat("\n\n ...within ", SUBGRP.VAR, " groups\n\n")
    cat("\n -----------------------------\n")

    out.file = paste(r03.PATH, out.PATH, ifelse(resp.var !="", resp.var, bin.var), "-", agegrp.var, "-bin-", SUBGRP.VAR, ".txt", sep="") # if not needed set to ""
    
    source(paste(r03.PATH, cmn.PATH, in.PREFIX, "-bin-SUBGRP.R", sep=""))
    if (STORE.RUNS) {
      CNTR.RESET = FALSE
    }
  }
  rm(SUBGRP.VAR)
}

# clean up workspace...
rm(u, cntr, agegrp.var, age.subset, SECTION.TITLE, DISP.HEADING, 
   w.boot.sub, w.BRR.sub, NH3.sub, zero.DT, positive.DT, healthy.sub, unhealthy.sub,
   NH3.sub.str, healthy.str, unhealthy.str)

#################################
# Last modified 11 December 2012. MT.
#################################


