########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

########################################################################
# Code is backward compatible with that used in:
#
# Borrell, L.N., M. Talih (2012). 
# Examining periodontal disease disparities among U.S. adults 20 years of age and older: 
# NHANES III (1988-1994) and NHANES 1999-2004. 
# Public Health Reports, 127, pp.497-506.
#
# Borrell, L.N., M. Talih (2011). 
# A Symmetrized Theil index measure of health disparities: 
# An example using dental caries in U.S. children and adolescents. 
# Statistics in Medicine, 30 (3), pp. 277-90. 
# First published online 5 November 2010. 
# DOI: 10.1002/sim.4114.
#
#########################################################################

###############################
# Last modified 11 December 2012
###############################

##################################################################
## Modify the following parameters to fine-tune report printout ##
##################################################################

## Whether to store BRR and bootstrap runs in workspace (FALSE will only keep track of SEs -- default)
STORE.RUNS = FALSE # implemented only for binary (disease indicator) individual-level outcome variables

## Whether to print group means and design-based standard errors
PRINT.MEANS = TRUE

## Whether to print differences in group means and design-based t-tests
PRINT.DIFF = TRUE

## Suppress means for groups with sample size n < 30 (set to zero for no suppression)
N.SUPPRESS = 30

#####################################################################
## Modify the following three parameters to match desired analysis ##
#####################################################################

## Specify disease indicator, (see DataSetup**.R and common/theil**-setup.R)
bin.var = "TC"

## Specify extent of disease measure (leave "" if none; see DataSetup**.R and common/theil**-setup.R)
resp.var = "LBXTC"

## Specify age group (see DataSetup**.R and common/theil**-setup.R)
agegrp.var = "adults25andOver"

##############################
## Do not modify code below ##
##############################

######################################################
## Setup the data (global variables set in MasterFile)

cat("\n Setting up the data...")
source(paste(r03.PATH, in.PATH, DATA.in, sep=""))
cat("... done!\n")

#####################
## Generate report(s)

cat("\n Generating output files and report for", ifelse(resp.var != "", resp.var, bin.var), agegrp.var, "...")
sink(paste(r03.PATH, out.PATH, ifelse(resp.var != "", resp.var, bin.var), "-", agegrp.var, "-REPORT.txt", sep=""))
source(paste(r03.PATH, in.PATH, in.PREFIX, "-", ifelse(resp.var != "", resp.var, bin.var), "-", agegrp.var, ".R", sep=""))
sink()
cat("... done!\n")

###########################################################################################################################

###############################################################################################
## Repeat for adults 20 and over (only educational attainment uses adults 25 years and over) ##
###############################################################################################

bin.var = "TC"
resp.var = "LBXTC"
agegrp.var = "adults20andOver"

cat("\n Generating output files and report for", ifelse(resp.var != "", resp.var, bin.var), agegrp.var, "...")
sink(paste(r03.PATH, out.PATH, ifelse(resp.var != "", resp.var, bin.var), "-", agegrp.var, "-REPORT.txt", sep=""))
source(paste(r03.PATH, in.PATH, in.PREFIX, "-", ifelse(resp.var != "", resp.var, bin.var), "-", agegrp.var, ".R", sep=""))
sink()
cat("... done!\n")

############################################################################################################################

#################################
# Last modified 11 December 2012. MT.
#################################

