########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

########################################
# Last modified: 11 December 2012. MT. #
########################################

###################################################################
## Code for generating supplemental Figure 1 and related figures ##
###################################################################

setwd("C:/***/pubperio/nhanes0508/output-files") # set to desired working directory

tab1 = read.table("LBXTC-adults20andOver-grp-AGEGRPN3.txt", sep = "\t", header = T, strip.white=T, as.is=T)
tab2 = read.table("LBXTC-adults25andOver-grp-AGEGRPN5.txt", sep = "\t", header = T, strip.white=T, as.is=T)

tab1[tab1$grouping != "ALL", "grouping"] = rep(rep(c("HSSEX", "DMARETHN2020", "NPIR", "US_BORN", "DMARETHN"), rep(102, 5)), 7)
tab2[tab2$grouping != "ALL", "grouping"] = rep(rep("NEDUC", 102), 6)

tab1[tab1$grouping != "ALL", "AGEGRPN3.level"] = rep(c("20-24", "25-44", "45-54", "55-64", "65-74", "75-79", "80+"), rep(510, 7))
tab2[tab2$grouping != "ALL", "AGEGRPN5.level"] = rep(c("25-44", "45-54", "55-64", "65-74", "75-79", "80+"), rep(102, 6))

subtitles = c("Sex", "Race/Ethnicity (excl. Other)", "Race/Ethnicity (incl. Other)", "Educational attainment", "Family income (% FPL)", "Country of birth")
labs =  c("HSSEX", "DMARETHN2020", "DMARETHN", "NEDUC", "NPIR", "US_BORN")
names(subtitles) = labs

titles = c("Ages 25-44", "Ages 45-54", "Ages 55-64", "Ages 65-74", "Ages 75-79", "Ages 80 and over")
ages = unique(tab1$AGEGRPN3.level)[-1]
names(titles) = ages

tab1 = tab1[tab1$alpha <= 16,]
tab2 = tab2[tab2$alpha <= 16,]

xat = c(0.5, 1, 2, 4, 8, 16)
xjit = c(0.02, 0.05, 0.1, 0.15, 0.3, 0.3)
x = tab1[tab1$AGEGRPN3.level == "25-44" & tab1$grouping == "HSSEX" & (tab1$type == "SRPW" | tab1$type == "S") & tab1$which == "aggregate", "alpha"]
xcond = is.element(x, xat) 


postscript(file = "choles-graphs-ci.eps", width=11, height=8.5, horizontal=T, family="Palatino", paper="letter")
par(mfrow=c(2,3))
for (g in labs) {
  if (g != "NEDUC") {
    tmp = tab1
    tmp$AGEGRP = tmp$AGEGRPN3.level
  }
  else {
    tmp = tab2
    tmp$AGEGRP = tmp$AGEGRPN5.level
  }

  for (j in ages) {

    f1 = ifelse(tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "aggregate", "alpha"] >= 0.5, tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "aggregate", "alpha"], 1-tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "aggregate", "alpha"])
    y1 = tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "aggregate", "index"]
    y1[!is.finite(y1)] = NA
    y1 = 1-exp(-f1*y1) + 0.05
    se1 = tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "aggregate", "BJ.se"]
    se1 = f1*exp(-f1*tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "aggregate", "index"])*se1
    lo1 = y1-1.959964*se1
    hi1 = y1+1.959964*se1
  
    f2 = ifelse(tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "aggregate", "alpha"] >= 0.5, tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "aggregate", "alpha"], 1-tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "aggregate", "alpha"])
    y2 = tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "aggregate", "index" ]
    y2[!is.finite(y2)] = NA
    y2 = 1-exp(-f2*y2) + 0.05
    se2 = tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "aggregate", "BJ.se"]
    se2 = f2*exp(-f2*tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "aggregate", "index"])*se2
    lo2 = y2-1.959964*se2
    hi2 = y2+1.959964*se2

    plot(x, y1, log="xy", main=paste(titles[j], "\n", subtitles[g]), xlab="Parameter value", ylab ="Standardized SRI (percent)", type="n", bty="n", axes=F, xlim=c(0.5, 16), ylim=c(0, 0.4)+0.05)
    axis(2, at=c(0, 0.01, 0.05, 0.10, 0.20, 0.30, 0.40)+0.05, labels=c(0, 1, 5, 10, 20, 30, 40))
    axis(1, at=xat, labels=xat)

    lines(x, y2, col=2, lwd=1, lty=2)
    arrows(x0=x[xcond]-xjit, y0=lo2[xcond], x1=x[xcond]-xjit, y1=hi2[xcond], angle=90, length=0.02, code=3, col=2, lty=1)
    lines(x, y1, col=4, lwd=1, lty=2)
    arrows(x0=x[xcond]+xjit, y0=lo1[xcond], x1=x[xcond]+xjit, y1=hi1[xcond], angle=90, length=0.02, code=3, col=4, lty=1)

    f1 = ifelse(tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "between", "alpha"] >= 0.5, tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "between", "alpha"], 1-tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "between", "alpha"])
    y1 = tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "between", "index"]
    y1[!is.finite(y1)] = NA
    y1 = 1-exp(-f1*y1) + 0.05
    se1 = tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "between", "BJ.se"]
    se1 = f1*exp(-f1*tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SRPW" | tmp$type == "S") & tmp$which == "between", "index"])*se1
    lo1 = y1-1.959964*se1
    hi1 = y1+1.959964*se1
  
    f2 = ifelse(tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "between", "alpha"] >= 0.5, tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "between", "alpha"], 1-tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "between", "alpha"])
    y2 = tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "between", "index" ]
    y2 = 1-exp(-f2*y2) + 0.05
    se2 = tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "between", "BJ.se"]
    se2 = f2*exp(-f2*tmp[tmp$AGEGRP == j & tmp$grouping == g & (tmp$type == "SREW" | tmp$type == "RS") & tmp$which == "between", "index"])*se2
    lo2 = y2-1.959964*se2
    hi2 = y2+1.959964*se2

    lines(x, y2, col=2, lwd=1)
    arrows(x0=x[xcond]-xjit, y0=lo2[xcond], x1=x[xcond]-xjit, y1=hi2[xcond], angle=90, length=0.02, code=3, col=2, lty=1)
    lines(x, y1, col=4, lwd=1)
    arrows(x0=x[xcond]+xjit, y0=lo1[xcond], x1=x[xcond]+xjit, y1=hi1[xcond], angle=90, length=0.02, code=3, col=4, lty=1)

    legend(x="topleft", legend=c("Pop.-weight. SRI: total", "Pop.-weight. SRI: between-group", "Eq.-weight. SRI: aggregate", "Eq.-weight. SRI: between-group", "(with 95% CIs)"), lty=c(2,1,2,1,0), lwd=c(1,1,1,1,1), col=c(4,4,2,2,0), bty="n") 

  }  
}

dev.off()


##########################################
## Last modified: 11 December 2012. MT. ##
##########################################


