########################################################################
# Talih, M. (2012).
# A reference-invariant health disparity index based on Renyi divergence.
# Annals of Applied Statistics. Accepted for publication.
########################################################################

########################################################################
# Code is backward compatible with that used in:
#
# Borrell, L.N., M. Talih (2012). 
# Examining periodontal disease disparities among U.S. adults 20 years of age and older: 
# NHANES III (1988-1994) and NHANES 1999-2004. 
# Public Health Reports, 127, pp.497-506.
#
# Borrell, L.N., M. Talih (2011). 
# A Symmetrized Theil index measure of health disparities: 
# An example using dental caries in U.S. children and adolescents. 
# Statistics in Medicine, 30 (3), pp. 277-90. 
# First published online 5 November 2010. 
# DOI: 10.1002/sim.4114.
#
#########################################################################

#################################
# Last modified 11 December 2012
#################################

####################################################################
## Modify the following headings as needed for report printout:

cat("\n\n Disparities in Dental Health in adults & seniors from NHANES 1999-2004:\n")
cat("\n R Report using the symmetrized Renyi index\n\n")

cat("\n\n References: \n\t Talih, M. (2012).\n\t A reference-invariant health disparity index based on Renyi divergence.\n\t Paper under review.\n")
cat("\n\t Borrell, L.N., M. Talih (2012). \n\t Examining periodontal disease disparities among US adults 20 years and older: \n\t NHANES III and NHANES 1999-2004. \n\t Public Health Reports. Accepted for publication.\n\n")

###############################################################
## Modify the following parameters to match desired analysis ##
###############################################################  

## Specify list of grouping variables to use in the output:
grp.list =  c("AGEGRP1", "INC3", "PIR", "EDUC", "HSSEX", "DMARETHN", "US_BORN")

## For analyses by population subgroup in grp.list within another grouping variable (leave as null character if not needed)
SUBGRP.LST = c("AGEGRP1", "INC3", "PIR")

## Modify report section title to match desired analysis:
SECTION.TITLE = "Periodontal Disease in Adults 20-64 and Seniors 65+"

## Modify the following heading as needed for report printout:
DISP.HEADING = "Health disparities in periodontal disease prevalence"

######################################################################################
## !!!!! Further global variables set in 'MasterFile' and in 'GenerateReport' !!!!! ##
######################################################################################

##########################################################################

##################################
## Do not modify the code below ##
##################################
  
cat("\n\n", SECTION.TITLE, "\n\n")

## Source setup syntax -- subset definitions are coded here...
source(paste(r03.PATH, cmn.PATH, in.PREFIX, "-setup.R", sep=""))

cat("\n ----------------------------------------------------------------------\n")
cat("\n\n\n", DISP.HEADING, "\n\n")
cat("\n ----------------------------------------------------------------------\n")

out.file = paste(r03.PATH, out.PATH, ifelse(resp.var !="", resp.var, bin.var), "-", agegrp.var, "-bin.txt", sep="") # if not needed set to ""
source(paste(r03.PATH, cmn.PATH, in.PREFIX, "-bin.R", sep=""))

if (SUBGRP.LST[1] > 0) {
  for (SUBGRP.VAR in SUBGRP.LST) {

    cat("\n -----------------------------\n")
    cat("\n\n ...within ", SUBGRP.VAR, " groups\n\n")
    cat("\n -----------------------------\n")  
  
    out.file = paste(r03.PATH, out.PATH, ifelse(resp.var !="", resp.var, bin.var), "-", agegrp.var, "-bin-", SUBGRP.VAR, ".txt", sep="") # if not needed set to ""  
  
    source(paste(r03.PATH, cmn.PATH, in.PREFIX, "-bin-SUBGRP.R", sep=""))
  }
  rm(SUBGRP.VAR)
}

# clean up workspace...
rm(agegrp.var, grp.list, age.subset, SUBGRP.LST, SECTION.TITLE, DISP.HEADING, 
   w.boot.sub, w.BRR.sub, NH3.sub, zero.DT, positive.DT, healthy.sub, unhealthy.sub,
   NH3.sub.str, healthy.str, unhealthy.str)

#################################
# Last modified 11 December 2012. MT.
#################################


